<?php

declare(strict_types=1);

namespace Drupal\menu_tree\TwigExtension;

use Drupal\menu_tree\MenuTreeItems;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Class MenuItemsTwigExtension.
 *
 * @package Drupal\menu_tree
 */
class MenuTreeTwigExtension extends AbstractExtension {

  /**
   * MenuItems definition.
   *
   * @var \Drupal\menu_Tree\MenuTreeItems
   */
  protected $menuTreeItems;

  /**
   * MenuItemsTwigExtension constructor.
   *
   * @param \Drupal\menu_tree\MenuTreeItems $menuTreeItems
   *   The MenuItems service.
   */
  public function __construct(MenuTreeItems $menuTreeItems) {
    $this->menuTreeItems = $menuTreeItems;
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions(): array {
    return [
      new TwigFunction('menu_tree',
        function ($menuId = NULL, $exclude = NULL) {
          return $this->menuTreeItems->getMenuTree($menuId, $exclude);
        },
        ['is_safe' => ['html']]
      ),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getName(): string {
    return 'menu_tree';
  }

}
